from distutils.core import setup

setup(
    name='pyli',
    version='0.2.0',
    author='thenoviceoof',
    author_email='thenoviceoof@gmail.com',
    packages=[],
    scripts=['bin/pyli'],
    url='https://github.com/thenoviceoof/pyli',
    license='LICENSE',
    description='Better python CLI integration',
    long_description=open('README.rst').read(),
    install_requires=[
    ],
)
